@@ -10,7 +10,7 @@ import sys
 import traceback
 from collections import ChainMap
 from subprocess import PIPE, Popen  # noqa: S404 (what other option, more secure that PIPE do we have? sockets?)
-from typing import Any, BinaryIO, Callable, Iterator, List, Optional, Tuple
+from typing import Any, BinaryIO, Callable, Iterator, List, Optional, Sequence, Tuple
 
 from markdown import Markdown
 from markupsafe import Markup
@@ -45,6 +45,7 @@ class PythonRenderer(BaseRenderer):
         "show_object_full_path": False,
         "show_category_heading": False,
         "show_if_no_docstring": False,
+        "show_signature": True,
         "show_signature_annotations": False,
         "show_source": True,
         "show_bases": True,
@@ -63,7 +64,8 @@ class PythonRenderer(BaseRenderer):
     **`show_root_members_full_path`** | `bool` | Show the full Python path of objects that are children of the root object (for example, classes in a module). When False, `show_object_full_path` overrides. | `False`
     **`show_category_heading`** | `bool` | When grouped by categories, show a heading for each category. | `False`
     **`show_if_no_docstring`** | `bool` | Show the object heading even if it has no docstring or children with docstrings. | `False`
-    **`show_signature_annotations`** | `bool` | Show the type annotations in methods and functions signatures. | `False`
+    **`show_signature`** | `bool` | Show method and function signatures. | `True`
+    **`show_signature_annotations`** | `bool` | Show the type annotations in method and function signatures. | `False`
     **`show_source`** | `bool` | Show the source code of this object. | `True`
     **`show_bases`** | `bool` | Show the base classes of a class. | `True`
     **`group_by_category`** | `bool` | Group the object's children by categories: attributes, classes, functions, methods, and modules. | `True`
@@ -95,8 +97,11 @@ class PythonRenderer(BaseRenderer):
             **{"config": final_config, data["category"]: data, "heading_level": heading_level, "root": True},
         )
 
-    def get_anchor(self, data: CollectorItem) -> str:  # noqa: D102 (ignore missing docstring)
-        return data.get("path")
+    def get_anchors(self, data: CollectorItem) -> Sequence[str]:  # noqa: D102 (ignore missing docstring)
+        try:
+            return (data["path"],)
+        except KeyError:
+            return ()
 
     def update_env(self, md: Markdown, config: dict) -> None:  # noqa: D102 (ignore missing docstring)
         super().update_env(md, config)
@@ -141,6 +146,21 @@ class PythonCollector(BaseCollector):
     Obviously one could use a single filter instead: `"!^_[^_]"`, which is the default.
     """
 
+    fallback_config = {"docstring_style": "markdown", "filters": ["!.*"]}
+    """The configuration used when falling back to re-collecting an object to get its anchor.
+
+    This configuration is used in [`Handlers.get_anchors`][mkdocstrings.handlers.base.Handlers.get_anchors].
+
+    When trying to fix (optional) cross-references, the autorefs plugin will try to collect
+    an object with every configured handler until one succeeds. It will then try to get
+    an anchor for it. It's because objects can have multiple identifiers (aliases),
+    for example their definition path and multiple import paths in Python.
+
+    When re-collecting the object, we have no use for its members, or for its docstring being parsed.
+    This is why the fallback configuration filters every member out, and uses the Markdown style,
+    which we know will not generate any warnings.
+    """
+
     def __init__(self, setup_commands: Optional[List[str]] = None) -> None:
         """Initialize the object.
 
