@@ -183,7 +183,7 @@ class MkdocstringsPlugin(BasePlugin):
             config["plugins"]["autorefs"] = autorefs
             log.debug(f"Added a subdued autorefs instance {autorefs!r}")
         # Add collector-based fallback in either case.
-        autorefs.get_fallback_anchor = self.handlers.get_anchor
+        autorefs.get_fallback_anchor = self.handlers.get_anchors
 
         mkdocstrings_extension = MkdocstringsExtension(extension_config, self.handlers, autorefs)
         config["markdown_extensions"].append(mkdocstrings_extension)
