@@ -14,10 +14,9 @@ import pytest
     ],
     indirect=["plugin"],
 )
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="material is not installed on Python 3.6")
-def test_render_themes_templates_python(plugin):
-    """Test rendering of a given theme's templates."""
-    modules = {
+@pytest.mark.parametrize(
+    "module",
+    [
         "mkdocstrings.extension",
         "mkdocstrings.inventory",
         "mkdocstrings.loggers",
@@ -25,9 +24,12 @@ def test_render_themes_templates_python(plugin):
         "mkdocstrings.handlers.base",
         "mkdocstrings.handlers.python",
         "mkdocstrings.handlers.rendering",
-    }
+    ],
+)
+@pytest.mark.skipif(sys.version_info < (3, 7), reason="material is not installed on Python 3.6")
+def test_render_themes_templates_python(module, plugin):
+    """Test rendering of a given theme's templates."""
     handler = plugin.handlers.get_handler("python")
     handler.renderer._update_env(plugin.md, plugin.handlers._config)  # noqa: WPS437
-    for identifier in modules:
-        data = handler.collector.collect(identifier, {})
-        handler.renderer.render(data, {})
+    data = handler.collector.collect(module, {})
+    handler.renderer.render(data, {})
